package com.bernhardriedl.projects.henonattractor.logic;

import java.awt.Canvas;
import java.awt.Color;
import java.awt.Dimension;
import java.awt.Graphics;

public class Iterator extends Canvas{

	private static final long serialVersionUID = 3607586826631133660L;

	private int resX;
	private int resY;
	
	private double a;
	private double b;
	
	private boolean animation=false;
	
	private Color [] Colors={
		Color.red,
		Color.yellow
	};
	
	/**
	 * Constructor
	 * @param a value of a
	 * @param b value of b
	 * @param animation true...animation, false:one pic
	 */
	
	public Iterator(double a, double b, boolean animation) {
		this.a=a;
		this.b=b;
		this.animation=animation;
	}

	/**
	 * paints the HenonAttractor
	 */
	
	public void paint(Graphics g) {
		this.setBackground(Color.black);
		
		/*
	     * get windows's dimensions
	     */

		Dimension m=this.getSize();
		
		this.resY=(int)m.getHeight();
		this.resX=(int)m.getWidth();
		
		/*
		 * starting point
		 */
		
		Point p=new Point(0, 0);
		
		/*
		 * draw all points
		 */
		
		for(int i=0;i<10000;i++) {
			g.setColor(Colors[(i%2)]);
			this.drawPoint(g, p);
			p=this.iterate(p);
		}
		
		/*
		 * handle animation
		 */
		
		if (animation) {
			
			/*
			 * do we need to reset a
			 * to start parameters?
			 */
			
			if (a >= 1.42) {
				a = 1.00;
				g.setColor(Color.black);
				g.fillRect(0, 0, resX, resY);
				}
			
			/*
			 * do we need to reset b
			 * to start parameters?
			 */
			
			if (b >= 0.5)
				b = 0.3;
			
			/*
			 * increase a
			 */

			this.a += 0.01;
			}
		}

	/**
	 * draw point as line
	 * @param g Graphics
	 * @param p Point
	 * */

	private void drawPoint(Graphics g, Point p){

		/*
		 * convert to screen coordinates
		 */
		
		int x1=(int)(resX/2*(p.getX()/2+1) );
		int y1=(int)(resY/2*(-p.getY()/2+1) );

		g.drawLine(x1, y1, x1, y1);
	}
	
	/**
	 * calculates new point
	 * @param p Point
	 * @return new point
	 */
	
	private Point iterate(Point p){
	  
    /*
     * start-parameters are
     * the coordinates of the
     * current point
     */
	  
    double xn=p.x;
    double yn=p.y;

    /*
     * calculate new coordinates
     */
    
    double x1=yn-a*xn*xn+1;
    double y1=b*xn;

    /*
     * return changed point
     */
    
    p.setLocation(x1, y1);
    return p;
  }
}