package com.bernhardriedl.projects.tools.gui;

import java.awt.Color;
import java.awt.Cursor;
import java.awt.Desktop;
import java.awt.Font;
import java.awt.event.MouseEvent;
import java.awt.event.MouseListener;
import java.net.URI;
import java.net.URISyntaxException;

import javax.swing.BorderFactory;
import javax.swing.JTextField;

public class URLTextField
	extends JTextField
	implements MouseListener {
	
	private static final long serialVersionUID = -4901705148394516036L;

	private URI url=null;
	
	private Desktop desktop=null;
	
	public URLTextField(String text, String url) {

		try {
			this.url=new URI(url);
		}
		
		catch (URISyntaxException e) {
			this.url=null;
		}
		
		if (Desktop.isDesktopSupported()) {
    	   Desktop tempDesktop = Desktop.getDesktop();
    	   		if (tempDesktop.isSupported(Desktop.Action.BROWSE)) {
    	   			this.desktop=tempDesktop;
    	   		}
    	}
		
		this.setText(text);
		
		this.setEditable(false);
    	this.setForeground(Color.BLUE);
    	this.setBorder(BorderFactory.createEmptyBorder());
    	this.setBackground(Color.WHITE);
    	this.setFont(new Font("Courier", 1, 11));
    	
    	this.setToolTipText(url);
    	
    	if (this.desktop!=null)
    		this.addMouseListener(this);
	}

	/**
	 * open url in browser
	 */
	
    public void mouseClicked(MouseEvent e) {
 
    	if (this.desktop!=null && this.url!=null) try {
            this.desktop.browse(this.url);
        }
        
        catch(Exception ex) {
        	
        	/**
        	 * do nothing
        	 */
        	
        }
    }

    /**
     * change cursor for links
     */
    
    public void mouseEntered(MouseEvent e) {
		this.setCursor(new Cursor(Cursor.HAND_CURSOR));		
	}
    
    /**
     * change back to default cursor
     */

	public void mouseExited(MouseEvent e) {
		this.setCursor(new Cursor(Cursor.DEFAULT_CURSOR));
	}

	/**
	 * not used
	 */
		
	public void mousePressed(MouseEvent e) {}
	public void mouseReleased(MouseEvent e) {}

}
